@@ -3,6 +3,8 @@ import sys
 from robotframework_ls.constants import NULL
 from robocorp_ls_core.robotframework_log import get_logger
 import threading
+from robotframework_ls.impl.robot_specbuilder import LibraryDoc
+from typing import Optional
 
 log = get_logger(__name__)
 
@@ -341,6 +343,30 @@ class LibspecManager(object):
     keywords that are available from those (properly caching data as needed).
     """
 
+    @classmethod
+    def get_robot_version(cls):
+        try:
+            import robot
+
+            v = str(robot.get_version())
+        except:
+            log.exception("Unable to get robot version.")
+            v = "unknown"
+        return v
+
+    @classmethod
+    def get_robot_major_version(cls):
+        robot_version = cls.get_robot_version()
+
+        major_version = 3
+        try:
+            if "." in robot_version:
+                major_version = int(robot_version.split(".")[0])
+        except:
+            log.exception("Unable to get robot major version.")
+
+        return major_version
+
     @classmethod
     def get_internal_libspec_dir(cls):
         from robotframework_ls import robot_config
@@ -355,12 +381,7 @@ class LibspecManager(object):
 
         digest = hashlib.sha256(pyexe).hexdigest()[:8]
 
-        try:
-            import robot
-
-            v = str(robot.get_version())
-        except:
-            v = "unknown"
+        v = cls.get_robot_version()
 
         # Note: _v1: information on the mtime of the libspec sources now available.
         return os.path.join(home, "specs", "%s_%s" % (digest, v))
@@ -625,16 +646,20 @@ class LibspecManager(object):
         # and have higher priority).
         iter_in = []
         for (_uri, info) in self._workspace_folder_uri_to_folder_info.items():
-            iter_in.append((info.libspec_canonical_filename_to_info, False))
+            if info.libspec_canonical_filename_to_info:
+                iter_in.append((info.libspec_canonical_filename_to_info, False))
 
         for (_uri, info) in self._pythonpath_folder_to_folder_info.items():
-            iter_in.append((info.libspec_canonical_filename_to_info, False))
+            if info.libspec_canonical_filename_to_info:
+                iter_in.append((info.libspec_canonical_filename_to_info, False))
 
         for (_uri, info) in self._additional_pythonpath_folder_to_folder_info.items():
-            iter_in.append((info.libspec_canonical_filename_to_info, False))
+            if info.libspec_canonical_filename_to_info:
+                iter_in.append((info.libspec_canonical_filename_to_info, False))
 
         for (_uri, info) in self._internal_folder_to_folder_info.items():
-            iter_in.append((info.libspec_canonical_filename_to_info, True))
+            if info.libspec_canonical_filename_to_info:
+                iter_in.append((info.libspec_canonical_filename_to_info, True))
 
         for canonical_filename_to_info, can_regenerate in iter_in:
             for canonical_spec_filename, info in list(
@@ -689,7 +714,13 @@ class LibspecManager(object):
         try:
             try:
                 call = [sys.executable]
-                call.extend("-m robot.libdoc --format XML:HTML".split())
+                major_version = self.get_robot_major_version()
+                if major_version < 4:
+                    call.extend("-m robot.libdoc --format XML:HTML".split())
+                else:
+                    # Use default values for libspec (--format XML:HTML is deprecated).
+                    call.extend("-m robot.libdoc".split())
+
                 if additional_path:
                     if os.path.exists(additional_path):
                         call.extend(["-P", additional_path])
@@ -808,7 +839,9 @@ class LibspecManager(object):
             return True
         return False
 
-    def get_library_info(self, libname, create=True, current_doc_uri=None):
+    def get_library_info(
+        self, libname, create=True, current_doc_uri=None
+    ) -> Optional[LibraryDoc]:
         """
         :param libname:
             It may be a library name, a relative path to a .py file or an
